Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: mojo/shell/public/cpp/lib/connection_impl.h

Issue 1705323003: ContentHandler -> ShellClientFactory (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delete
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/public/cpp/content_handler_factory.h ('k') | mojo/shell/public/cpp/lib/connection_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/public/cpp/lib/connection_impl.h
diff --git a/mojo/shell/public/cpp/lib/connection_impl.h b/mojo/shell/public/cpp/lib/connection_impl.h
index 7d9c55e0e1b1f51ba246c7254e8075005fd131d3..1346e257a9613b877a0c7e9139538d2fceb036c4 100644
--- a/mojo/shell/public/cpp/lib/connection_impl.h
+++ b/mojo/shell/public/cpp/lib/connection_impl.h
@@ -45,7 +45,8 @@ class ConnectionImpl : public Connection {
void SetRemoteInterfaceProviderConnectionErrorHandler(
const Closure& handler) override;
bool GetRemoteApplicationID(uint32_t* remote_id) const override;
- bool GetRemoteContentHandlerID(uint32_t* content_handler_id) const override;
+ bool GetRemoteShellClientFactoryID(
+ uint32_t* shell_client_factory_id) const override;
void AddRemoteIDCallback(const Closure& callback) override;
bool AllowsInterface(const std::string& interface_name) const override;
shell::mojom::InterfaceProvider* GetRemoteInterfaces() override;
@@ -53,15 +54,15 @@ class ConnectionImpl : public Connection {
base::WeakPtr<Connection> GetWeakPtr() override;
void OnGotRemoteIDs(uint32_t target_application_id,
- uint32_t content_handler_id);
+ uint32_t shell_client_factory_id);
const std::string connection_url_;
const std::string remote_url_;
uint32_t remote_id_;
// The id of the content_handler is only available once the callback from
// establishing the connection is made.
- uint32_t content_handler_id_;
+ uint32_t shell_client_factory_id_;
bool remote_ids_valid_;
std::vector<Closure> remote_id_callbacks_;
« no previous file with comments | « mojo/shell/public/cpp/content_handler_factory.h ('k') | mojo/shell/public/cpp/lib/connection_impl.cc » ('j') | no next file with comments »
@@ -53,15 +54,15 @@ class ConnectionImpl : public Connection {
const std::string remote_url_;
uint32_t remote_id_;
- // The id of the content_handler is only available once the callback from
+ // The id of the shell_client_factory is only available once the callback from
// establishing the connection is made.

Powered by Google App Engine
This is Rietveld 408576698